"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RunActionSummaryViewer = exports.RulesActionSummaryViewer = exports.ConfigActionSummaryViewer = void 0;
const code_analyzer_core_1 = require("@salesforce/code-analyzer-core");
const StylingUtil_1 = require("../utils/StylingUtil");
const messages_1 = require("../messages");
class AbstractActionSummaryViewer {
    display;
    constructor(display) {
        this.display = display;
    }
    displaySummaryHeader() {
        this.display.displayLog((0, StylingUtil_1.toStyledHeader)((0, messages_1.getMessage)(messages_1.BundleName.ActionSummaryViewer, 'common.summary-header')));
    }
    displayLineSeparator() {
        this.display.displayLog("");
    }
    displayLogFileInfo(logFile) {
        this.display.displayLog((0, messages_1.getMessage)(messages_1.BundleName.ActionSummaryViewer, 'common.logfile-location'));
        this.display.displayLog((0, StylingUtil_1.indent)(logFile));
    }
}
class ConfigActionSummaryViewer extends AbstractActionSummaryViewer {
    constructor(display) {
        super(display);
    }
    view(logFile, outfile) {
        this.displaySummaryHeader();
        this.displayLineSeparator();
        if (outfile) {
            this.displayOutfile(outfile);
            this.displayLineSeparator();
        }
        this.displayLogFileInfo(logFile);
    }
    displayOutfile(outfile) {
        this.display.displayLog((0, messages_1.getMessage)(messages_1.BundleName.ActionSummaryViewer, 'config-action.outfile-location'));
        this.display.displayLog((0, StylingUtil_1.indent)(outfile));
    }
}
exports.ConfigActionSummaryViewer = ConfigActionSummaryViewer;
class RulesActionSummaryViewer extends AbstractActionSummaryViewer {
    constructor(display) {
        super(display);
    }
    view(ruleSelection, logFile) {
        // Start with separator to cleanly break from anything that's already been logged.
        this.displayLineSeparator();
        this.displaySummaryHeader();
        this.displayLineSeparator();
        if (ruleSelection.getCount() === 0) {
            this.display.displayLog((0, messages_1.getMessage)(messages_1.BundleName.ActionSummaryViewer, 'rules-action.found-no-rules'));
        }
        else {
            this.displayRuleSelection(ruleSelection);
        }
        this.displayLineSeparator();
        this.displayLogFileInfo(logFile);
    }
    displayRuleSelection(ruleSelection) {
        this.display.displayLog((0, messages_1.getMessage)(messages_1.BundleName.ActionSummaryViewer, 'rules-action.rules-total', [ruleSelection.getCount(), ruleSelection.getEngineNames().length]));
        for (const engineName of ruleSelection.getEngineNames()) {
            const ruleCountForEngine = ruleSelection.getRulesFor(engineName).length;
            this.display.displayLog((0, StylingUtil_1.indent)((0, messages_1.getMessage)(messages_1.BundleName.ActionSummaryViewer, 'rules-action.rules-item', [ruleCountForEngine, engineName])));
        }
    }
}
exports.RulesActionSummaryViewer = RulesActionSummaryViewer;
class RunActionSummaryViewer extends AbstractActionSummaryViewer {
    constructor(display) {
        super(display);
    }
    view(results, logFile, outfiles) {
        // Start with separator to cleanly break from anything that's already been logged.
        this.displayLineSeparator();
        this.displaySummaryHeader();
        this.displayLineSeparator();
        if (results.getViolationCount() === 0) {
            this.display.displayLog((0, messages_1.getMessage)(messages_1.BundleName.ActionSummaryViewer, 'run-action.found-no-violations'));
        }
        else {
            this.displayResultsSummary(results);
        }
        this.displayLineSeparator();
        if (outfiles.length > 0) {
            this.displayOutfiles(outfiles);
            this.displayLineSeparator();
        }
        this.displayLogFileInfo(logFile);
    }
    displayResultsSummary(results) {
        this.display.displayLog((0, messages_1.getMessage)(messages_1.BundleName.ActionSummaryViewer, 'run-action.violations-total', [results.getViolationCount(), this.countUniqueFiles(results.getViolations())]));
        for (const sev of Object.values(code_analyzer_core_1.SeverityLevel)) {
            // Some of the keys will be numbers, since the enum is numerical. Skip those.
            if (typeof sev !== 'string') {
                continue;
            }
            const sevCount = results.getViolationCountOfSeverity(code_analyzer_core_1.SeverityLevel[sev]);
            if (sevCount > 0) {
                this.display.displayLog((0, StylingUtil_1.indent)((0, messages_1.getMessage)(messages_1.BundleName.ActionSummaryViewer, 'run-action.violations-item', [sevCount, sev])));
            }
        }
    }
    countUniqueFiles(violations) {
        const fileSet = new Set();
        violations.forEach(v => {
            const primaryLocation = v.getCodeLocations()[v.getPrimaryLocationIndex()];
            const file = primaryLocation.getFile();
            if (file) {
                fileSet.add(file);
            }
        });
        return fileSet.size;
    }
    displayOutfiles(outfiles) {
        this.display.displayLog((0, messages_1.getMessage)(messages_1.BundleName.ActionSummaryViewer, 'run-action.outfiles-total'));
        for (const outfile of outfiles) {
            this.display.displayLog((0, StylingUtil_1.indent)(outfile));
        }
    }
}
exports.RunActionSummaryViewer = RunActionSummaryViewer;
//# sourceMappingURL=ActionSummaryViewer.js.map